#!/bin/bash

# use_compcache (run as *root*)
# - Loads compcache and related modules.
# - Sets up swap device.
#
# Usage: setup_compcache <size in KB>
#

MOD_PARAM=""
SIZE_KB="$1"
SIZE_KB="$1"

LSMOD_BIN=/sbin/lsmod
INSMOD_BIN=/sbin/insmod
MODPROBE_BIN=/sbin/modprobe
SWAPON_BIN=/sbin/swapon
UDEVADM_BIN=/sbin/udevadm

INSMOD()
{
	MOD_NAME="$1"
	EXIST=`$LSMOD_BIN | grep "$MOD_NAME"`
	if [ "$EXIST" != "" ]; then
		echo "Module: $MOD_NAME already loaded."
	else
		if [ ! -f $MOD_NAME.ko ]; then
			echo "Module: $MOD_NAME not found in current directory"
		else
			$INSMOD_BIN $MOD_NAME.ko "$MOD_PARAM"
		fi
	fi
}

# Some distos already have LZO de/compress modules
echo "Loading modules ..."
$MODPROBE_BIN -q lzo_compress  || INSMOD lzo1x_compress
$MODPROBE_BIN -q lzo_decompress || INSMOD lzo1x_decompress
INSMOD tlsf

if [ -z "$SIZE_KB" ]; then
	echo "compcache size not given. Using default (25% of RAM)."
else
	MOD_PARAM="compcache_size_kbytes=$SIZE_KB"
fi
INSMOD compcache 

# /dev/ramzswap0 is not available immediately after insmod returns
# So, let udev complete its work before we do swapon
#i$UDEVADM_BIN settle

#The eeepc does not have udevadm
sleep 1 

# Set it as swap device with highest priority
EXIST=`cat /proc/swaps | grep compcache`
if [ "$EXIST" = "" ]; then
	echo "Setting up swap device ..."
	$SWAPON_BIN /dev/ramzswap0 -p 100
	if [ "$?" = "0" ]; then
		echo "Done!"
	else
		echo "Could not add compcache swap device."
	fi
else
	echo "compcache swap device already active."
fi

exit 0

